@@ -3,6 +3,8 @@ import re
 import os
 import argparse
 import statistics
+from statistics import mean
+import pathlib
 from typing import Dict, List
 import sys
 
@@ -223,7 +225,7 @@ def parse_file_kernel():
     """
     data_dict = {}
 
-    for address, dirs, files in os.walk('/home/german/Рабочий стол/pract/webstat/web_spl/media/'):
+    for address, dirs, files in os.walk(str(pathlib.Path.cwd())+'/web_spl/media/'):
         for file in files:
             if not file.endswith('messtat'):
                 continue
@@ -237,7 +239,7 @@ def parse_file_kernel():
             data_file_without_zero = [ [ dd for dd in d if dd != 0.00] for d in data_file_with_zero]
             data_file_kernel_len = [len(d) for d in data_file_without_zero]
 
-            data_dict[file.name] = {
+            data_dict[file.name.split('//')[1]] = {
                 'data'              : data_file_with_zero,
                 'data_without_zero' : data_file_without_zero,
 
